searchData={"items":[{"type":"module","title":"Cldr.Currency","doc":"Defines a currency structure and a set of functions to manage the validity of a currency code\nand to return metadata for currencies.","ref":"Cldr.Currency.html"},{"type":"function","title":"Cldr.Currency.annotated?/1","doc":"Returns a boolean indicating if a given\ncurrency is annotated.\n\nAnnotated means that the currency description\nhas annotations (comments inside parenthesis).\nThis is mostly found in currency codes used as\nfinancial instruments (not legal tender).","ref":"Cldr.Currency.html#annotated?/1"},{"type":"function","title":"Arguments - Cldr.Currency.annotated?/1","doc":"* `currency` is a `t:Cldr.Currency`","ref":"Cldr.Currency.html#annotated?/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.annotated?/1","doc":"* `true` or `false`","ref":"Cldr.Currency.html#annotated?/1-returns"},{"type":"function","title":"Cldr.Currency.currencies_for_locale/4","doc":"Returns a map of the metadata for all currencies for\na given locale.","ref":"Cldr.Currency.html#currencies_for_locale/4"},{"type":"function","title":"Arguments - Cldr.Currency.currencies_for_locale/4","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module\n\n* `currency_status` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status.\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","ref":"Cldr.Currency.html#currencies_for_locale/4-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currencies_for_locale/4","doc":"* `{:ok, currency_map}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Currency.html#currencies_for_locale/4-returns"},{"type":"function","title":"Example - Cldr.Currency.currencies_for_locale/4","doc":"=> Cldr.Currency.currencies_for_locale(\"en\", MyApp.Cldr)\n  {:ok,\n   %{\n     FJD: %Cldr.Currency{\n       cash_digits: 2,\n       cash_rounding: 0,\n       code: \"FJD\",\n       count: %{one: \"Fijian dollar\", other: \"Fijian dollars\"},\n       digits: 2,\n       from: nil,\n       iso_digits: 2,\n       name: \"Fijian Dollar\",\n       narrow_symbol: \"$\",\n       rounding: 0,\n       symbol: \"FJD\",\n       tender: true,\n       to: nil\n     },\n     SUR: %Cldr.Currency{\n       cash_digits: 2,\n       cash_rounding: 0,\n       code: \"SUR\",\n       count: %{one: \"Soviet rouble\", other: \"Soviet roubles\"},\n       digits: 2,\n       from: nil,\n       iso_digits: nil,\n       name: \"Soviet Rouble\",\n       narrow_symbol: nil,\n       rounding: 0,\n       symbol: \"SUR\",\n       tender: true,\n       to: nil\n     },\n     ...\n    }}","ref":"Cldr.Currency.html#currencies_for_locale/4-example"},{"type":"function","title":"Cldr.Currency.currencies_for_locale!/4","doc":"Returns a map of the metadata for all currencies for\na given locale and raises on error.","ref":"Cldr.Currency.html#currencies_for_locale!/4"},{"type":"function","title":"Arguments - Cldr.Currency.currencies_for_locale!/4","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module\n\n* `currency_status` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status.\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","ref":"Cldr.Currency.html#currencies_for_locale!/4-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currencies_for_locale!/4","doc":"* `{:ok, currency_map}` or\n\n* raises an exception","ref":"Cldr.Currency.html#currencies_for_locale!/4-returns"},{"type":"function","title":"Example - Cldr.Currency.currencies_for_locale!/4","doc":"#=> MyApp.Cldr.Currency.currencies_for_locale!(\"en\")\n  %{\n    FJD: %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"FJD\",\n      count: %{one: \"Fijian dollar\", other: \"Fijian dollars\"},\n      digits: 2,\n      from: nil,\n      iso_digits: 2,\n      name: \"Fijian Dollar\",\n      narrow_symbol: \"$\",\n      rounding: 0,\n      symbol: \"FJD\",\n      tender: true,\n      to: nil\n    },\n    SUR: %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"SUR\",\n      count: %{one: \"Soviet rouble\", other: \"Soviet roubles\"},\n      digits: 2,\n      from: nil,\n      iso_digits: nil,\n      name: \"Soviet Rouble\",\n      narrow_symbol: nil,\n      rounding: 0,\n      symbol: \"SUR\",\n      tender: true,\n      to: nil\n    },\n    ...\n   }","ref":"Cldr.Currency.html#currencies_for_locale!/4-example"},{"type":"function","title":"Cldr.Currency.currency_filter/3","doc":"Return only those currencies meeting the\nfilter criteria.","ref":"Cldr.Currency.html#currency_filter/3"},{"type":"function","title":"Arguments - Cldr.Currency.currency_filter/3","doc":"* `currency` is a `t:Cldr.Currency`, a list of `t:Cldr.Currency` or a\n  map where the values of each item is a `Cldr.Currency.t`\n\n* `only` is `:all`, `:current`, `:historic`, `:tender`\n  `unannotated` or a list of one or more status or currency codes.\n  The default is `:all`\n\n* `except` is `:current`, `:historic`, `:tender`\n  `unannotated` or a list of one or more status or currency codes.\n  The default is `nil`","ref":"Cldr.Currency.html#currency_filter/3-arguments"},{"type":"function","title":"Currency Status - Cldr.Currency.currency_filter/3","doc":"A currency may be in current use or of historic interest only. It\nmay or may not be legal tender. And it may mostly be used as a financial\ninstrument.  To help return the most useful currencies the\ncurrency status code acts as follows:\n\n* `:all`, the default, returns all currencies\n\n* `:current` returns those currencies that have a `:to`\n  date of nil and which also is a known ISO4217 currency\n\n* `:historic` is the opposite of `:current`\n\n* `:tender` is a currency that is legal tender\n\n* `:unannotated` is a currency that doesn't have\n  \"(some string)\" in its name.  These are usually\n  financial instruments.","ref":"Cldr.Currency.html#currency_filter/3-currency-status"},{"type":"function","title":"Cldr.Currency.currency_for_code/3","doc":"Returns the currency metadata for the requested currency code.","ref":"Cldr.Currency.html#currency_for_code/3"},{"type":"function","title":"Arguments - Cldr.Currency.currency_for_code/3","doc":"* `currency_or_currency_code` is a `binary` or `atom` representation\n    of an ISO 4217 currency code, or a `t:Cldr.Currency` struct.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `options` is a `Keyword` list of options. The default is\n  `[]`.","ref":"Cldr.Currency.html#currency_for_code/3-arguments"},{"type":"function","title":"Options - Cldr.Currency.currency_for_code/3","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`","ref":"Cldr.Currency.html#currency_for_code/3-options"},{"type":"function","title":"Returns - Cldr.Currency.currency_for_code/3","doc":"* A `{:ok, currency}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Currency.html#currency_for_code/3-returns"},{"type":"function","title":"Examples - Cldr.Currency.currency_for_code/3","doc":"iex> Cldr.Currency.currency_for_code(\"AUD\", MyApp.Cldr)\n    {:ok,\n      %Cldr.Currency{\n        cash_digits: 2,\n        cash_rounding: 0,\n        code: \"AUD\",\n        count: %{one: \"Australian dollar\", other: \"Australian dollars\"},\n        digits: 2,\n        iso_digits: 2,\n        name: \"Australian Dollar\",\n        narrow_symbol: \"$\",\n        rounding: 0,\n        symbol: \"A$\",\n        tender: true\n    }}\n\n    iex> Cldr.Currency.currency_for_code(\"THB\", MyApp.Cldr)\n    {:ok,\n      %Cldr.Currency{\n        cash_digits: 2,\n        cash_rounding: 0,\n        code: \"THB\",\n        count: %{one: \"Thai baht\", other: \"Thai baht\"},\n        digits: 2,\n        iso_digits: 2,\n        name: \"Thai Baht\",\n        narrow_symbol: \"฿\",\n        rounding: 0,\n        symbol: \"THB\",\n        tender: true\n    }}","ref":"Cldr.Currency.html#currency_for_code/3-examples"},{"type":"function","title":"Cldr.Currency.currency_for_code!/3","doc":"Returns the currency metadata for the requested currency code.","ref":"Cldr.Currency.html#currency_for_code!/3"},{"type":"function","title":"Arguments - Cldr.Currency.currency_for_code!/3","doc":"* `currency_or_currency_code` is a `binary` or `atom` representation\n    of an ISO 4217 currency code, or a `t:Cldr.Currency` struct.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module\n\n* `options` is a `Keyword` list of options.","ref":"Cldr.Currency.html#currency_for_code!/3-arguments"},{"type":"function","title":"Options - Cldr.Currency.currency_for_code!/3","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`","ref":"Cldr.Currency.html#currency_for_code!/3-options"},{"type":"function","title":"Returns - Cldr.Currency.currency_for_code!/3","doc":"* A `t:Cldr.Current.t/0` or\n\n* raises an exception","ref":"Cldr.Currency.html#currency_for_code!/3-returns"},{"type":"function","title":"Examples - Cldr.Currency.currency_for_code!/3","doc":"iex> Cldr.Currency.currency_for_code!(\"AUD\", MyApp.Cldr)\n    %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"AUD\",\n      count: %{one: \"Australian dollar\", other: \"Australian dollars\"},\n      digits: 2,\n      iso_digits: 2,\n      name: \"Australian Dollar\",\n      narrow_symbol: \"$\",\n      rounding: 0,\n      symbol: \"A$\",\n      tender: true\n    }\n\n    iex> Cldr.Currency.currency_for_code!(\"THB\", MyApp.Cldr)\n    %Cldr.Currency{\n      cash_digits: 2,\n      cash_rounding: 0,\n      code: \"THB\",\n      count: %{one: \"Thai baht\", other: \"Thai baht\"},\n      digits: 2,\n      iso_digits: 2,\n      name: \"Thai Baht\",\n      narrow_symbol: \"฿\",\n      rounding: 0,\n      symbol: \"THB\",\n      tender: true\n    }","ref":"Cldr.Currency.html#currency_for_code!/3-examples"},{"type":"function","title":"Cldr.Currency.currency_format_from_locale/1","doc":"Returns the effective currency format for a given locale.","ref":"Cldr.Currency.html#currency_format_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Currency.currency_format_from_locale/1","doc":"* `locale` a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.","ref":"Cldr.Currency.html#currency_format_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currency_format_from_locale/1","doc":"* Either `:accounting` or `:currency`.","ref":"Cldr.Currency.html#currency_format_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Currency.currency_format_from_locale/1","doc":"iex> {:ok, locale} = Cldr.validate_locale(\"en\", MyApp.Cldr)\n    iex> Cldr.Currency.currency_format_from_locale locale\n    :currency\n\n    iex> {:ok, locale} = Cldr.validate_locale(\"en-AU-u-cu-eur\", MyApp.Cldr)\n    iex> Cldr.Currency.currency_format_from_locale locale\n    :currency\n\n    iex> {:ok, locale} = Cldr.validate_locale(\"en-AU-u-cu-eur-cf-account\", MyApp.Cldr)\n    iex> Cldr.Currency.currency_format_from_locale locale\n    :accounting","ref":"Cldr.Currency.html#currency_format_from_locale/1-examples"},{"type":"function","title":"Cldr.Currency.currency_format_from_locale/2","doc":"Returns the effective currency format for a given locale.","ref":"Cldr.Currency.html#currency_format_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Currency.currency_format_from_locale/2","doc":"* `locale` a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.Currency.html#currency_format_from_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currency_format_from_locale/2","doc":"* Either `:accounting` or `:currency`.","ref":"Cldr.Currency.html#currency_format_from_locale/2-returns"},{"type":"function","title":"Examples - Cldr.Currency.currency_format_from_locale/2","doc":"iex> Cldr.Currency.currency_format_from_locale(\"en\", MyApp.Cldr)\n    :currency\n\n    iex> Cldr.Currency.currency_format_from_locale(\"en-AU-u-cu-eur\", MyApp.Cldr)\n    :currency\n\n    iex> Cldr.Currency.currency_format_from_locale(\"en-AU-u-cu-eur-cf-account\", MyApp.Cldr)\n    :accounting","ref":"Cldr.Currency.html#currency_format_from_locale/2-examples"},{"type":"function","title":"Cldr.Currency.currency_from_locale/1","doc":"Returns the effective currency for a given locale.","ref":"Cldr.Currency.html#currency_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Currency.currency_from_locale/1","doc":"* `locale` is a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.","ref":"Cldr.Currency.html#currency_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currency_from_locale/1","doc":"* A ISO 4217 currency code as an upcased atom.","ref":"Cldr.Currency.html#currency_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Currency.currency_from_locale/1","doc":"iex> {:ok, locale} = Cldr.validate_locale(\"en\", MyApp.Cldr)\n    iex> Cldr.Currency.currency_from_locale locale\n    :USD\n\n    iex> {:ok, locale} = Cldr.validate_locale(\"en-AU\", MyApp.Cldr)\n    iex> Cldr.Currency.currency_from_locale locale\n    :AUD\n\n    iex> Cldr.Currency.currency_from_locale(\"en-GB\")\n    :GBP","ref":"Cldr.Currency.html#currency_from_locale/1-examples"},{"type":"function","title":"Cldr.Currency.currency_from_locale/2","doc":"Returns the effective currency for a given locale.","ref":"Cldr.Currency.html#currency_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Currency.currency_from_locale/2","doc":"* `locale` is any valid locale name returned by\n  `Cldr.known_locale_names/1`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.Currency.html#currency_from_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currency_from_locale/2","doc":"* A ISO 4217 currency code as an upcased atom.","ref":"Cldr.Currency.html#currency_from_locale/2-returns"},{"type":"function","title":"Examples - Cldr.Currency.currency_from_locale/2","doc":"iex> Cldr.Currency.currency_from_locale(\"fr-CH\", MyApp.Cldr)\n    :CHF\n\n    iex> Cldr.Currency.currency_from_locale(\"fr-CH-u-cu-INR\", MyApp.Cldr)\n    :INR","ref":"Cldr.Currency.html#currency_from_locale/2-examples"},{"type":"function","title":"Cldr.Currency.currency_history_for_locale/1","doc":"Returns a list of historic and the current\ncurrency for a given locale.","ref":"Cldr.Currency.html#currency_history_for_locale/1"},{"type":"function","title":"Arguments - Cldr.Currency.currency_history_for_locale/1","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.Currency.html#currency_history_for_locale/1-arguments"},{"type":"function","title":"Example - Cldr.Currency.currency_history_for_locale/1","doc":"iex> Cldr.Currency.currency_history_for_locale(\"en\", MyApp.Cldr)\n    {:ok,\n      %{\n        USD: %{from: ~D[1792-01-01], to: nil},\n        USN: %{tender: false},\n        USS: %{from: nil, tender: false, to: ~D[2014-03-01]}\n      }\n    }","ref":"Cldr.Currency.html#currency_history_for_locale/1-example"},{"type":"function","title":"Cldr.Currency.currency_history_for_locale/2","doc":"","ref":"Cldr.Currency.html#currency_history_for_locale/2"},{"type":"function","title":"Cldr.Currency.currency_strings/4","doc":"Returns a map that matches a currency string to a\ncurrency code.\n\nA currency string is a localised name or symbol\nrepresenting a currency in a locale-specific manner.","ref":"Cldr.Currency.html#currency_strings/4"},{"type":"function","title":"Arguments - Cldr.Currency.currency_strings/4","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.\n\n* `:only` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","ref":"Cldr.Currency.html#currency_strings/4-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currency_strings/4","doc":"* `{:ok, currency_string_map}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Currency.html#currency_strings/4-returns"},{"type":"function","title":"Example - Cldr.Currency.currency_strings/4","doc":"=> Cldr.Currency.currency_strings(\"en\", MyApp.Cldr)\n    {:ok,\n     %{\n       \"mexican silver pesos\" => :MXP,\n       \"sudanese dinar\" => :SDD,\n       \"bad\" => :BAD,\n       \"rsd\" => :RSD,\n       \"swazi lilangeni\" => :SZL,\n       \"zairean new zaire\" => :ZRN,\n       \"guyanaese dollars\" => :GYD,\n       \"equatorial guinean ekwele\" => :GQE,\n       ...\n    }}\n\n    # Currencies match all currency status'\n    => Cldr.Currency.currency_strings \"en\", MyApp.Cldr, [:tender, :current, :unannotated]\n    {:ok,\n     %{\n       \"rsd\" => :RSD,\n       \"swazi lilangeni\" => :SZL,\n       \"guyanaese dollars\" => :GYD,\n       \"syrian pound\" => :SYP,\n       \"scr\" => :SCR,\n       \"bangladeshi takas\" => :BDT,\n       \"netherlands antillean guilders\" => :ANG,\n       \"pen\" => :PEN,\n       ...\n    }}","ref":"Cldr.Currency.html#currency_strings/4-example"},{"type":"function","title":"Cldr.Currency.currency_strings!/4","doc":"Returns a map that matches a currency string to a\ncurrency code or raises an exception.\n\nA currency string is a localised name or symbol\nrepresenting a currency in a locale-specific manner.","ref":"Cldr.Currency.html#currency_strings!/4"},{"type":"function","title":"Arguments - Cldr.Currency.currency_strings!/4","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.\n\n* `currency_status` is `:all`, `:current`, `:historic`,\n  `unannotated` or `:tender`; or a list of one or more status.\n  The default is `:all`. See `Cldr.Currency.currency_filter/2`.","ref":"Cldr.Currency.html#currency_strings!/4-arguments"},{"type":"function","title":"Returns - Cldr.Currency.currency_strings!/4","doc":"* `{:ok, currency_string_map}` or\n\n* raises an exception.","ref":"Cldr.Currency.html#currency_strings!/4-returns"},{"type":"function","title":"Example - Cldr.Currency.currency_strings!/4","doc":"=> Cldr.Currency.currency_strings!(\"en\", MyApp.Cldr)\n    %{\n      \"mexican silver pesos\" => :MXP,\n      \"sudanese dinar\" => :SDD,\n      \"bad\" => :BAD,\n      \"rsd\" => :RSD,\n      \"swazi lilangeni\" => :SZL,\n      \"zairean new zaire\" => :ZRN,\n      \"guyanaese dollars\" => :GYD,\n      \"equatorial guinean ekwele\" => :GQE,\n      ...\n    }","ref":"Cldr.Currency.html#currency_strings!/4-example"},{"type":"function","title":"Cldr.Currency.current?/1","doc":"Returns a boolean indicating if a given\ncurrency is current.\n\nCurrent means that the currency is in current\nuse.","ref":"Cldr.Currency.html#current?/1"},{"type":"function","title":"Arguments - Cldr.Currency.current?/1","doc":"* `currency` is a `t:Cldr.Currency`","ref":"Cldr.Currency.html#current?/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.current?/1","doc":"* `true` or `false`","ref":"Cldr.Currency.html#current?/1-returns"},{"type":"function","title":"Cldr.Currency.current_currency_for_territory/1","doc":"Returns the current currency for a given territory.","ref":"Cldr.Currency.html#current_currency_for_territory/1"},{"type":"function","title":"Arguments - Cldr.Currency.current_currency_for_territory/1","doc":"* `territory` is any valid territory name returned by\n  `Cldr.known_territories/0`","ref":"Cldr.Currency.html#current_currency_for_territory/1-arguments"},{"type":"function","title":"Examples - Cldr.Currency.current_currency_for_territory/1","doc":"iex> Cldr.Currency.current_currency_for_territory(:US)\n    :USD\n\n    iex> Cldr.Currency.current_currency_for_territory(:AU)\n    :AUD","ref":"Cldr.Currency.html#current_currency_for_territory/1-examples"},{"type":"function","title":"Cldr.Currency.current_currency_from_locale/1","doc":"Returns the current currency from a given locale.\n\nThis function does not consider the `U` extenion\nparameters `cu` or `rg`. It is recommended to us\n`Cldr.Currency.currency_from_locale/1` in most\ncircumstances.","ref":"Cldr.Currency.html#current_currency_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Currency.current_currency_from_locale/1","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.Currency.html#current_currency_from_locale/1-arguments"},{"type":"function","title":"Examples - Cldr.Currency.current_currency_from_locale/1","doc":"iex> Cldr.Currency.current_currency_from_locale(\"en\", MyApp.Cldr)\n    :USD\n\n    iex> Cldr.Currency.current_currency_from_locale(\"en-AU\", MyApp.Cldr)\n    :AUD","ref":"Cldr.Currency.html#current_currency_from_locale/1-examples"},{"type":"function","title":"Cldr.Currency.current_currency_from_locale/2","doc":"","ref":"Cldr.Currency.html#current_currency_from_locale/2"},{"type":"function","title":"Cldr.Currency.current_territory_currencies/0","doc":"Returns a mapping from a territory code to its\ncurrent currency code.\n\nIf a territory has no current currency (like\nAntartica, territory code `:AQ`) then no\nmapping is returned for that territory.","ref":"Cldr.Currency.html#current_territory_currencies/0"},{"type":"function","title":"Returns - Cldr.Currency.current_territory_currencies/0","doc":"* A map of `{territory_code => currency.code}`","ref":"Cldr.Currency.html#current_territory_currencies/0-returns"},{"type":"function","title":"Cldr.Currency.display_name/2","doc":"Return the display name for a currency.\n\nThe display name is useful for UI\nuses, for example in menus. The display name\nis typically capitalized for stand-alone use\nwhere as the display name returned by\n`Cldr.Currency.pluralize/4` is typically\nlower-cased for use within sentences.","ref":"Cldr.Currency.html#display_name/2"},{"type":"function","title":"Arguments - Cldr.Currency.display_name/2","doc":"* `currency` is any currency code returned by `Cldr.Currency.known_currencies/0` or\n  a `t:Cldr.Currency` struct returned by `Cldr.Currency.currency_for_code/3`.","ref":"Cldr.Currency.html#display_name/2-arguments"},{"type":"function","title":"Options - Cldr.Currency.display_name/2","doc":"* `:locale` is any locale returned by `Cldr.Locale.new!/2`. The\n  default is `Cldr.get_locale/0`.\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.Currency.html#display_name/2-options"},{"type":"function","title":"Returns - Cldr.Currency.display_name/2","doc":"* `{:ok, display_name}`\n\n* or `{:error, {exception, reason}}`","ref":"Cldr.Currency.html#display_name/2-returns"},{"type":"function","title":"Examples - Cldr.Currency.display_name/2","doc":"iex> Cldr.Currency.display_name :AUD, backend: MyApp.Cldr\n    {:ok, \"Australian Dollar\"}\n\n    iex> Cldr.Currency.display_name \"AUD\", backend: MyApp.Cldr, locale: \"fr\"\n    {:ok, \"dollar australien\"}\n\n    iex> Cldr.Currency.display_name \"EUR\", backend: MyApp.Cldr, locale: \"de\"\n    {:ok, \"Euro\"}\n\n    iex> Cldr.Currency.display_name \"ZZZ\", backend: MyApp.Cldr\n    {:error, {Cldr.UnknownCurrencyError, \"The currency \\\"ZZZ\\\" is invalid\"}}","ref":"Cldr.Currency.html#display_name/2-examples"},{"type":"function","title":"Cldr.Currency.display_name!/2","doc":"Return the display name for a currency or\nraises and exception on error.\n\nThe display name is useful for UI\nuses, for example in menus. The display name\nis typically capitalized for stand-alone use\nwhere as the display name returned by\n`Cldr.Currency.pluralize/4` is typically\nlower-cased for use within sentences.","ref":"Cldr.Currency.html#display_name!/2"},{"type":"function","title":"Arguments - Cldr.Currency.display_name!/2","doc":"* `currency` is any currency code returned by `Cldr.Currency.known_currencies/0` or\n  a `t:Cldr.Currency` struct returned by `Cldr.Currency.currency_for_code/3`.","ref":"Cldr.Currency.html#display_name!/2-arguments"},{"type":"function","title":"Options - Cldr.Currency.display_name!/2","doc":"* `:locale` is any locale returned by `Cldr.Locale.new!/2`. The\n  default is `Cldr.get_locale/0`.\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.Currency.html#display_name!/2-options"},{"type":"function","title":"Returns - Cldr.Currency.display_name!/2","doc":"* `display_name`\n\n* or raises an exception","ref":"Cldr.Currency.html#display_name!/2-returns"},{"type":"function","title":"Examples - Cldr.Currency.display_name!/2","doc":"iex> Cldr.Currency.display_name! :AUD, backend: MyApp.Cldr\n    \"Australian Dollar\"\n\n    iex> Cldr.Currency.display_name! \"AUD\", backend: MyApp.Cldr, locale: \"fr\"\n    \"dollar australien\"\n\n    iex> Cldr.Currency.display_name! \"EUR\", backend: MyApp.Cldr, locale: \"de\"\n    \"Euro\"\n\n    #=> Cldr.Currency.display_name! \"ZZZ\", backend: MyApp.Cldr\n    ** (Cldr.UnknownCurrencyError) The currency \"ZZZ\" is invalid","ref":"Cldr.Currency.html#display_name!/2-examples"},{"type":"function","title":"Cldr.Currency.historic?/1","doc":"Returns a boolean indicating if a given\ncurrency is historic.\n\nHistoric means that the currency is no longer\nin use.","ref":"Cldr.Currency.html#historic?/1"},{"type":"function","title":"Arguments - Cldr.Currency.historic?/1","doc":"* `currency` is a `t:Cldr.Currency`","ref":"Cldr.Currency.html#historic?/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.historic?/1","doc":"* `true` or `false`","ref":"Cldr.Currency.html#historic?/1-returns"},{"type":"function","title":"Cldr.Currency.known_currencies/0","doc":"","ref":"Cldr.Currency.html#known_currencies/0"},{"type":"function","title":"Cldr.Currency.known_currency?/1","doc":"","ref":"Cldr.Currency.html#known_currency?/1"},{"type":"function","title":"Cldr.Currency.known_currency_code/1","doc":"Returns a 2-tuple indicating if the supplied currency code is known.","ref":"Cldr.Currency.html#known_currency_code/1"},{"type":"function","title":"Arguments - Cldr.Currency.known_currency_code/1","doc":"* `currency_code` is a `binary` or `atom` representing an ISO4217\n  currency code.","ref":"Cldr.Currency.html#known_currency_code/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.known_currency_code/1","doc":"* `{:ok, currency_code}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Currency.html#known_currency_code/1-returns"},{"type":"function","title":"Examples - Cldr.Currency.known_currency_code/1","doc":"iex> Cldr.Currency.known_currency_code(\"AUD\")\n    {:ok, :AUD}\n\n    iex> Cldr.Currency.known_currency_code(\"GGG\")\n    {:error, {Cldr.UnknownCurrencyError, \"The currency \\\"GGG\\\" is invalid\"}}","ref":"Cldr.Currency.html#known_currency_code/1-examples"},{"type":"function","title":"Cldr.Currency.known_currency_code?/1","doc":"Returns a boolean indicating if the supplied currency code is known.","ref":"Cldr.Currency.html#known_currency_code?/1"},{"type":"function","title":"Arguments - Cldr.Currency.known_currency_code?/1","doc":"* `currency_code` is a `binary` or `atom` representing an ISO4217\n  currency code.","ref":"Cldr.Currency.html#known_currency_code?/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.known_currency_code?/1","doc":"* `true` or `false`","ref":"Cldr.Currency.html#known_currency_code?/1-returns"},{"type":"function","title":"Examples - Cldr.Currency.known_currency_code?/1","doc":"iex> Cldr.Currency.known_currency_code?(\"AUD\")\n    true\n\n    iex> Cldr.Currency.known_currency_code?(\"GGG\")\n    false\n\n    iex> Cldr.Currency.known_currency_code?(:XCV)\n    false","ref":"Cldr.Currency.html#known_currency_code?/1-examples"},{"type":"function","title":"Cldr.Currency.known_currency_codes/0","doc":"Returns a list of all known currency codes.","ref":"Cldr.Currency.html#known_currency_codes/0"},{"type":"function","title":"Example - Cldr.Currency.known_currency_codes/0","doc":"iex> Cldr.Currency.known_currency_codes()","ref":"Cldr.Currency.html#known_currency_codes/0-example"},{"type":"function","title":"Cldr.Currency.new/2","doc":"Returns a `Currency` struct created from the arguments.","ref":"Cldr.Currency.html#new/2"},{"type":"function","title":"Arguments - Cldr.Currency.new/2","doc":"* `currency` is a private use currency code in a format defined by\n  [ISO4217](https://en.wikipedia.org/wiki/ISO_4217)\n  which is `X` followed by two alphanumeric characters.\n\n* `options` is a map of options representing the optional elements of\n  the `Cldr.Currency.t` struct.","ref":"Cldr.Currency.html#new/2-arguments"},{"type":"function","title":"Options - Cldr.Currency.new/2","doc":"* `:name` is the name of the currency. Required.\n* `:digits` is the precision of the currency. Required.\n* `:symbol` is the currency symbol. Optional.\n* `:narrow_symbol` is an alternative narrow symbol. Optional.\n* `:round_nearest` is the rounding precision such as `0.05`. Optional.\n* `:alt_code` is an alternative currency code for application use.\n* `:cash_digits` is the precision of the currency when used as cash. Optional.\n* `:cash_round_nearest` is the rounding precision when used as cash\n  such as `0.05`. Optional.","ref":"Cldr.Currency.html#new/2-options"},{"type":"function","title":"Returns - Cldr.Currency.new/2","doc":"* `{:ok, Cldr.Currency.t}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Currency.html#new/2-returns"},{"type":"function","title":"Examples - Cldr.Currency.new/2","doc":"iex> Cldr.Currency.new(:XAC, name: \"XAC currency\", digits: 0)\n    {:ok,\n     %Cldr.Currency{\n       alt_code: :XAC,\n       cash_digits: 0,\n       cash_rounding: nil,\n       code: :XAC,\n       count: %{other: \"XAC currency\"},\n       digits: 0,\n       from: nil,\n       iso_digits: 0,\n       name: \"XAC currency\",\n       narrow_symbol: nil,\n       rounding: 0,\n       symbol: \"XAC\",\n       tender: false,\n       to: nil\n     }}\n    iex> Cldr.Currency.new(:XBC)\n    {:error, {Cldr.CurrencyAlreadyDefined, \"Currency :XBC is already defined.\"}}\n    iex> MyApp.Cldr.Currency.new(:XAB, name: \"Private Use Name\")\n    {:error, \"Required options are missing. Required options are [:name, :digits]\"}\n    iex> Cldr.Currency.new(:ZAA, name: \"Invalid Private Use Name\", digits: 0)\n    {:error, {Cldr.UnknownCurrencyError, \"The currency :ZAA is invalid\"}}","ref":"Cldr.Currency.html#new/2-examples"},{"type":"function","title":"Cldr.Currency.pluralize/4","doc":"Returns the appropriate currency display name for the `currency`, based\non the plural rules in effect for the `locale`.","ref":"Cldr.Currency.html#pluralize/4"},{"type":"function","title":"Arguments - Cldr.Currency.pluralize/4","doc":"* `number` is an integer, float or `Decimal`.\n\n* `currency` is any currency returned by `Cldr.Currency.known_currencies/0`.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.\n\n* `options` is a keyword list of options.","ref":"Cldr.Currency.html#pluralize/4-arguments"},{"type":"function","title":"Options - Cldr.Currency.pluralize/4","doc":"* `:locale` is any locale returned by `Cldr.Locale.new!/2`. The\n  default is ` .get_locale/1`.","ref":"Cldr.Currency.html#pluralize/4-options"},{"type":"function","title":"Returns - Cldr.Currency.pluralize/4","doc":"* `{:ok, plural_string}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.Currency.html#pluralize/4-returns"},{"type":"function","title":"Examples - Cldr.Currency.pluralize/4","doc":"iex> Cldr.Currency.pluralize(1, :USD, MyApp.Cldr)\n    {:ok, \"US dollar\"}\n\n    iex> Cldr.Currency.pluralize(3, :USD, MyApp.Cldr)\n    {:ok, \"US dollars\"}\n\n    iex> Cldr.Currency.pluralize(12, :USD, MyApp.Cldr, locale: :zh)\n    {:ok, \"美元\"}\n\n    iex> Cldr.Currency.pluralize(12, :USD, MyApp.Cldr, locale: :fr)\n    {:ok, \"dollars des États-Unis\"}\n\n    iex> Cldr.Currency.pluralize(1, :USD, MyApp.Cldr, locale: :fr)\n    {:ok, \"dollar des États-Unis\"}","ref":"Cldr.Currency.html#pluralize/4-examples"},{"type":"function","title":"Cldr.Currency.private_currencies/0","doc":"Returns a map of private currencies.\n\nThese comprise all currencies created with\n`Cldr.Currency.new/2`.","ref":"Cldr.Currency.html#private_currencies/0"},{"type":"function","title":"Cldr.Currency.private_currency_codes/0","doc":"Returns a list of all private currency codes.","ref":"Cldr.Currency.html#private_currency_codes/0"},{"type":"function","title":"Cldr.Currency.string_comparator/2","doc":"","ref":"Cldr.Currency.html#string_comparator/2"},{"type":"function","title":"Cldr.Currency.strings_for_currency/3","doc":"Returns the strings associated with a currency\nin a given locale.","ref":"Cldr.Currency.html#strings_for_currency/3"},{"type":"function","title":"Arguments - Cldr.Currency.strings_for_currency/3","doc":"* `currency` is an ISO4217 currency code\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Currency.html#strings_for_currency/3-arguments"},{"type":"function","title":"Returns - Cldr.Currency.strings_for_currency/3","doc":"* A list of strings or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Currency.html#strings_for_currency/3-returns"},{"type":"function","title":"Example - Cldr.Currency.strings_for_currency/3","doc":"iex> Cldr.Currency.strings_for_currency(:AUD, \"en\", MyApp.Cldr) |> Enum.sort\n    [\"a$\", \"aud\", \"australian dollar\", \"australian dollars\"]\n\n    iex> Cldr.Currency.strings_for_currency(:AUD, \"de\", MyApp.Cldr) |> Enum.sort\n    [\"au$\", \"aud\", \"australische dollar\", \"australischer dollar\"]\n\n    iex> Cldr.Currency.strings_for_currency(:AUD, \"zh\", MyApp.Cldr) |> Enum.sort\n    [\"au$\", \"aud\", \"澳大利亚元\"]","ref":"Cldr.Currency.html#strings_for_currency/3-example"},{"type":"function","title":"Cldr.Currency.tender?/1","doc":"Returns a boolean indicating if a given\ncurrency is legal tender.\n\nLegal tender is anything recognized by law\nas a means to settle a public or private debt or\nmeet a financial obligation.","ref":"Cldr.Currency.html#tender?/1"},{"type":"function","title":"Arguments - Cldr.Currency.tender?/1","doc":"* `currency` is a `t:Cldr.Currency`","ref":"Cldr.Currency.html#tender?/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.tender?/1","doc":"* `true` or `false`","ref":"Cldr.Currency.html#tender?/1-returns"},{"type":"function","title":"Cldr.Currency.territory_currencies/0","doc":"Returns a mapping of all ISO3166 territory\ncodes and a list of historic and the current\ncurrency for those territories.","ref":"Cldr.Currency.html#territory_currencies/0"},{"type":"function","title":"Example - Cldr.Currency.territory_currencies/0","doc":"iex> Cldr.Currency.territory_currencies() |> Map.get(:LT)\n    %{\n      EUR: %{from: ~D[2015-01-01], to: nil},\n      LTL: %{from: nil, to: ~D[2014-12-31]},\n      LTT: %{from: nil, to: ~D[1993-06-25]},\n      SUR: %{from: nil, to: ~D[1992-10-01]}\n    }","ref":"Cldr.Currency.html#territory_currencies/0-example"},{"type":"function","title":"Cldr.Currency.territory_currencies/1","doc":"Returns a list of currencies associated with\na given territory.","ref":"Cldr.Currency.html#territory_currencies/1"},{"type":"function","title":"Arguments - Cldr.Currency.territory_currencies/1","doc":"* `territory` is any valid ISO 3166 Alpha-2 territory code.\n   See `Cldr.validate_territory/1`.","ref":"Cldr.Currency.html#territory_currencies/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.territory_currencies/1","doc":"* `{:ok, map}` where `map` has as its key a `t:Cldr.Currency`\n  struct and the value is a map of validity dates for that\n  currency; or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Currency.html#territory_currencies/1-returns"},{"type":"function","title":"Example - Cldr.Currency.territory_currencies/1","doc":"iex> Cldr.Currency.territory_currencies(:LT)\n    {:ok, %{\n      EUR: %{from: ~D[2015-01-01], to: nil},\n      LTL: %{from: nil, to: ~D[2014-12-31]},\n      LTT: %{from: nil, to: ~D[1993-06-25]},\n      SUR: %{from: nil, to: ~D[1992-10-01]}\n    }}","ref":"Cldr.Currency.html#territory_currencies/1-example"},{"type":"function","title":"Cldr.Currency.territory_currencies!/1","doc":"Returns a list of currencies associated with\na given territory.","ref":"Cldr.Currency.html#territory_currencies!/1"},{"type":"function","title":"Arguments - Cldr.Currency.territory_currencies!/1","doc":"* `territory` is any valid ISO 3166 Alpha-2 territory code.\n   See `Cldr.validate_territory/1`.","ref":"Cldr.Currency.html#territory_currencies!/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.territory_currencies!/1","doc":"* `map` where `map` has as its key a `t:Cldr.Currency`\n  struct and the value is a map of validity dates for that\n  currency; or\n\n* raises an exception.","ref":"Cldr.Currency.html#territory_currencies!/1-returns"},{"type":"function","title":"Example - Cldr.Currency.territory_currencies!/1","doc":"iex> Cldr.Currency.territory_currencies!(:LT)\n    %{\n      EUR: %{from: ~D[2015-01-01], to: nil},\n      LTL: %{from: nil, to: ~D[2014-12-31]},\n      LTT: %{from: nil, to: ~D[1993-06-25]},\n      SUR: %{from: nil, to: ~D[1992-10-01]}\n    }","ref":"Cldr.Currency.html#territory_currencies!/1-example"},{"type":"function","title":"Cldr.Currency.unannotated?/1","doc":"Returns a boolean indicating if a given\ncurrency is unannotated.\n\nAnnotated means that the currency description\nhas annotations (comments inside parenthesis).\nThis is mostly found in currency codes used as\nfinancial instruments (not legal tender).","ref":"Cldr.Currency.html#unannotated?/1"},{"type":"function","title":"Arguments - Cldr.Currency.unannotated?/1","doc":"* `currency` is a `t:Cldr.Currency`","ref":"Cldr.Currency.html#unannotated?/1-arguments"},{"type":"function","title":"Returns - Cldr.Currency.unannotated?/1","doc":"* `true` or `false`","ref":"Cldr.Currency.html#unannotated?/1-returns"},{"type":"function","title":"Cldr.Currency.validate_new_currency/1","doc":"Determines is a new currency is already\ndefined.","ref":"Cldr.Currency.html#validate_new_currency/1"},{"type":"function","title":"Example - Cldr.Currency.validate_new_currency/1","doc":"iex> Cldr.Currency.validate_new_currency :XAD\n    {:ok, :XAD}\n\n    iex> Cldr.Currency.validate_new_currency :USD\n    {:error, {Cldr.CurrencyAlreadyDefined, \"Currency :USD is already defined.\"}}","ref":"Cldr.Currency.html#validate_new_currency/1-example"},{"type":"type","title":"Cldr.Currency.code/0","doc":"","ref":"Cldr.Currency.html#t:code/0"},{"type":"type","title":"Cldr.Currency.currency_status/0","doc":"","ref":"Cldr.Currency.html#t:currency_status/0"},{"type":"type","title":"Cldr.Currency.filter/0","doc":"","ref":"Cldr.Currency.html#t:filter/0"},{"type":"type","title":"Cldr.Currency.format/0","doc":"","ref":"Cldr.Currency.html#t:format/0"},{"type":"type","title":"Cldr.Currency.t/0","doc":"","ref":"Cldr.Currency.html#t:t/0"},{"type":"type","title":"Cldr.Currency.territory/0","doc":"","ref":"Cldr.Currency.html#t:territory/0"},{"type":"module","title":"Cldr.Eternal","doc":"This module implements bindings around what should be an eternal ETS table,\nor at least until you decide to terminate it. It works by using \"bouncing\"\nGenServers which come up as needed to provide an heir for the ETS table. It\noperates as follows:\n\n1. An ETS table is created with the provided name and options.\n2. Two GenServers are started, an `owner` and an `heir`. The ETS table is gifted\n  to the `owner`, and has the `heir` set as the heir.\n3. If the `owner` crashes, the `heir` becomes the owner, and a new GenServer\n  is started and assigned the role of `heir`.\n4. If an `heir` dies, we attempt to start a new GenServer and notify the `owner`\n  so that they may change the assigned `heir`.\n\nThis means that there should always be an `heir` to your table, which should\nensure that you don't lose anything inside ETS.","ref":"Cldr.Eternal.html"},{"type":"function","title":"Cldr.Eternal.heir/1","doc":"Returns the heir of a given ETS table.","ref":"Cldr.Eternal.html#heir/1"},{"type":"function","title":"Examples - Cldr.Eternal.heir/1","doc":"iex> Cldr.Eternal.heir(:my_table)","ref":"Cldr.Eternal.html#heir/1-examples"},{"type":"function","title":"Cldr.Eternal.owner/1","doc":"Returns the owner of a given ETS table.","ref":"Cldr.Eternal.html#owner/1"},{"type":"function","title":"Examples - Cldr.Eternal.owner/1","doc":"iex> Cldr.Eternal.owner(:my_table)","ref":"Cldr.Eternal.html#owner/1-examples"},{"type":"function","title":"Cldr.Eternal.start/3","doc":"Functionally equivalent to `start_link/3`, except that the link to the starting\nprocess is removed after the table is started.","ref":"Cldr.Eternal.html#start/3"},{"type":"function","title":"Examples - Cldr.Eternal.start/3","doc":"iex> Cldr.Eternal.start(:table1, [], [quiet: true])\n\n    iex> Cldr.Eternal.start(:table2, [:compressed], [quiet: true])\n\n    iex> Cldr.Eternal.start(:table3, [], [quiet: true])","ref":"Cldr.Eternal.html#start/3-examples"},{"type":"function","title":"Cldr.Eternal.start_link/3","doc":"Creates a new ETS table using the provided `ets_opts`.\n\nThese options are passed through as-is, with the exception of prepending the\n`:public` and `:named_table` options. Seeing as you can't execute inside the\nGenServers, your table will have to be public to be interacted with.","ref":"Cldr.Eternal.html#start_link/3"},{"type":"function","title":"Options - Cldr.Eternal.start_link/3","doc":"You may provide a third parameter containing Eternal options:\n\n- `:name` - override the default naming scheme and use a custom name for this\n  table. Remember to use this name when calling `stop/1`.\n- `:quiet` - by default, Eternal logs debug messages. Setting this to true will\n  disable this logging.","ref":"Cldr.Eternal.html#start_link/3-options"},{"type":"function","title":"Examples - Cldr.Eternal.start_link/3","doc":"iex> Cldr.Eternal.start_link(:table1, [], [quiet: true])\n\n    iex> Cldr.Eternal.start_link(:table2, [:compressed], [quiet: true])\n\n    iex> Cldr.Eternal.start_link(:table3, [], [quiet: true])","ref":"Cldr.Eternal.html#start_link/3-examples"},{"type":"function","title":"Cldr.Eternal.stop/1","doc":"Terminates both servers in charge of a given ETS table.\n\nNote: this will terminate your ETS table.","ref":"Cldr.Eternal.html#stop/1"},{"type":"function","title":"Examples - Cldr.Eternal.stop/1","doc":"iex> Cldr.Eternal.stop(:my_table)\n    :ok","ref":"Cldr.Eternal.html#stop/1-examples"},{"type":"type","title":"Cldr.Eternal.on_start/0","doc":"","ref":"Cldr.Eternal.html#t:on_start/0"},{"type":"type","title":"Cldr.Eternal.table/0","doc":"","ref":"Cldr.Eternal.html#t:table/0"},{"type":"exception","title":"Cldr.CurencyNotSavedError","doc":"Exception raised when an attempt is save a new currency\nto the ETS table is not successful.","ref":"Cldr.CurencyNotSavedError.html"},{"type":"extras","title":"Cldr Currencies","doc":"# Cldr Currencies\n\nPackages the currency definitions from [CLDR](http://cldr.unicode.org) into a set of functions\nto return currency data.","ref":"readme.html"},{"type":"extras","title":"Installation - Cldr Currencies","doc":"The package can be installed by adding `ex_cldr_currencies` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_cldr_currencies, \"~> 2.13\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Defining private use currencies - Cldr Currencies","doc":"[ISO4217](https://en.wikipedia.org/wiki/ISO_4217) permits the creation of private use currencies. These are denoted by currencies that start with \"X\" followed by two characters.  New currencies can be created with `Cldr.Currency.new/2` however in order to do so a supervisor must be started which maintains an `:ets` table that holds the custom currencies.\n\nSince the currencies are stored in an `:ets` table they are transient and will be lost on application restart. It is the developers responsibility to define the required private use currencies on application restart.","ref":"readme.html#defining-private-use-currencies"},{"type":"extras","title":"Starting the private use currency supervisor - Cldr Currencies","doc":"The simplest way to start the private use currency supervisor is:\n```elixir\niex> Cldr.Currency.start_link()\n```\n\nThe preferred method however is to add the supervisor to your applications supervision tree. In your application module (ie the one that includes `use Application`):\n```elixir\ndefmodule MyApp do\n  use Application\n\n  def start(_type, _args) do\n    # Start the service which maintains the\n    # :ets table that holds the private use currencies\n    children = [\n      Cldr.Currency\n      ...\n    ]\n\n    opts = [strategy: :one_for_one, name: MoneyTest.Supervisor]\n    Supervisor.start_link(children, opts)\n    \n    # Load your custom currencies now that the\n    # Cldr.Currency genserver is running\n    # load_my_custom_currencies()\n  end\nend\n```","ref":"readme.html#starting-the-private-use-currency-supervisor"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr_Currencies v2.16.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.16.0 released on April 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-16-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR 45](https://cldr.unicode.org/index/downloads/cldr-45) data as used in `ex_cldr` version 2.38.0.\n\n* Default the currency display name when there is no other pluralization data. This is required due to some data generation changes in the JSON data used by `ex_cldr`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.15.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.15.1 released on November 3rd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-15-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compilation warnings on Elixir 1.16.\n\n* Fixes typespec for `Cldr.Currency.currency_history_for_locale/1`. Thanks to @Munksgaard for the report and PR. Closes #11, Closes #12.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.15.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.15.0 released on January 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-15-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Currency.current_territory_currencies/1` and `MyApp.Cldr.Currency.current_territory_currencies/0` that returns a mapping from territory code from currency type for all territories that have a current currency.  Thanks for @lawik for the inspiration.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.14.3 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.14.3 released on January 27th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-14-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Cldr.Currency.current_currency_for_territory/1` returns `nil` if the territory, like `:AQ` has no currency. Thanks to @lawik for the report. Closes #8.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.14.2 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.14.2 released on October 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-14-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Currency.currency_strings/2` to include narrow symbols. Note that where duplicate symbols exist (same symbol for more than one currency) they are are omitted from the list of strings since they are ambiguous (unless one of them is a historic currency in which case the current currency is kept and the historic removed).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.14.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.14.1 released on June 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-14-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Currency.currency_from_locale/2` when the first argument is a `t:Cldr.LanguageTag.t/0`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.14.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.14.0 released on June 4th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-14-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Currency.currency_for_code/2` and the same function for backend modules.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.13.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.13.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-13-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix deprecated `use Mix.Config` and replace with `import Config` in configuration files.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Currency.currency_format_from_locale/2` support a binary language tag and optional backend","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.12.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.12.0 released on October 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-12-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40) via [ex_cldr version 2.24](https://hex.pm/packages/ex_cldr/2.24.0)\n\n* Fix licence name","ref":"changelog.html#enhancements"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Currencies v2.12.0-rc.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.12.0-rc.1 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-12-0-rc-1"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr_Currencies v2.12.0-rc.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.12.0-rc.0 released on October 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-12-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support for CLDR version 40.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.11.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.11.1 released on August 4th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-11-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add missing docs and specs. Thanks to @tcitworld for the report. Closes #5.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.11.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.11.0 released on July 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-11-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds support for the `Cldr.DisplayName` protocol for `t:Cldr.Currency` structs.\n\n* Updated to [ex_cldr version 2.23.0](https://hex.pm/packages/ex_cldr/2.23.0) which changes the names of some of the field in the \"-u-\" extension to match the CLDR canonical name. In particular the field name `currency_format` changes to `cf`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.10.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.10.0 released on June 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-10-1"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Constrain `ex_doc` to `:dev` and `:release` environments only, and `:optional` to make sure.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.10.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.10.0 released on June 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-10-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Allow `%Currency{}` structs in `currency_for_code/3`. Thanks to @jeroenvisser101 for the PR. [Improves the performance](https://github.com/elixir-cldr/cldr_currencies/pull/4) by up to 40x when validating currencies when the currency has already been pre-constructed.\n\n* Add implementation of the `Inspect` protocol for `t:Cldr.Currency` structs.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.9.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.9.0 released on April 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-9-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Depends upon `ex_cldr` version 2.20 which embodies CLDR39 data.\n\n* Add `Cldr.Currency.display_name/2` that returns a localized display name suitable for use in UI applications.\n\n* Add implementation of `String.Chars` and `Cldr.Chars` protocols for `t:Cldr.Currency` structs.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.9.0-rc.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.9.0-rc.1 released on March 24th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-9-0-rc-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Currency.display_name/2` that returns a localized display name suitable for use in UI applications.\n\n* Add implementation of `String.Chars` and `Cldr.Chars` protocols for `t:Cldr.Currency` structs.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.9.0-rc.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.9.0-rc.0 released on March 19th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-9-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Depends upon `ex_cldr` version 2.20 which embodies CLDR39 data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.8.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.8.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.7.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.7.0 released on September 25th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Use `Cldr.default_backend!/0` when available since `Cldr.default_backend/0` is deprecated as of `ex_cldr` version `2.18.0`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.6.2 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.6.2 released on August 31st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-6-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Uses `Supervisor.child_spec/2` for `eternal` workers to remove deprecation warning on Elixir 1.11","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.6.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.6.1 released on July 19th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-6-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Make dialyzer happy. The `@spec`s for `Cldr.Eternal.start_link/1` and `Cldr.Eternal.start_link/0` however remain a mystery and are commented out for now - success typing seems happy nevertheless.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.6.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.6.0 released on July 18th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-6-0"},{"type":"extras","title":"Breaking change - Changelog","doc":"* Remove `Cldr.Currency.make_currency_code/1` whose need is replaced by `Cldr.validate_currency/1`.","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Deprecate `Cldr.Currency.known_currency?/1` in favour of `Cldr.Currency.known_currency_code?/1`\n\n* Deprecate `Cldr.Currency.known_currencies/0` in favour of `Cldr.Currency.known_currency_codes/0`","ref":"changelog.html#deprecations"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support the creation of private use currencies with `Cldr.Currency.new/2`. Newly created private use currencies are stored in an `:ets` table which means that currencies will need to be recreated on each application restart. Creating the currencies is a developer responsibility although this may change in the future.  In order to create currencies a supervisor and `:ets` table owner must be started.  See the [README](README.md) for further details on adding the private use currency store to your application supervision tree.\n\n* Add `:alt_code` to the `Cldr.Currency` struct. When creating a new currency, the currency code must conform to ISO4217 meaning that any new code must be in the \"private use\" range. This in turn means that the currency code must start with \"X\" and be three characters long. Many crypto currencies have either conflicting currency codes (do not comply with ISO4217 private use) or are invalid codes (longer than three characters).  The `:alt_code` can be used to store an arbitrary alternative currency code than can be used to identify cryptocurrencies by a more familiar code.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.5.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.5.0 released on May 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Currency.currency_from_locale/{1, 2}`\n\n* Add `Cldr.Currency.current_currency_from_locale/1`\n\n* Add `Cldr.Currency.current_currency_from_territory/1`\n\n* Add `Cldr.Currency.currency_format_from_locale/1`\n\n* Add ` .currency_from_locale/{1, 2}`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.4,1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.4.1 released on November 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-4-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* In some rare cases, currency strings have a trailing `.`. These are now removed when producing currency strings that are used for parsing money amounts in `ex_money`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.4.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.4.0 released on November 6th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds the options `:only` and `:except` to `Cldr.Currency.filter_currencies/3`. These options are exercised in [ex_money](https://hex.pm/packages/ex_money) in the `Money.parse/2` function to limited parsed user input to a particular set of currencies.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.3.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.3.0 released on March 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR version 35.0.0](http://cldr.unicode.org/index/downloads/cldr-35) released on March 27th 2019.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.2.5 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.2.5 released on March 15th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-2-5"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.2.4 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.2.4 released on March 15th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-2-4"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Makes generation of documentation for backend modules optional.  This is implemented by the `:generate_docs` option to the backend configuration.  The default is `true`. For example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    default_locale: \"en-001\",\n    locales: [\"en\", \"ja\"],\n    gettext: MyApp.Gettext,\n    generate_docs: false\nend\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.2.3 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.2.3 released on March 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-2-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix or silence all remaining dialyzer warnings for real this time","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.2.2 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.2.2 released on March 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-2-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix or silence all remaining dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.2.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.2.1 released on March 6th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix or silence dialyzer warnings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.2.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.2.0 released on February 23nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"This release adds mapping data from a territory to a list of currencies and functions to access them. This allows for identifying the current currency for a given locale.\n\n* Adds `Cldr.Currency.currency_history_for_locale/2`\n* Adds `Cldr.Currency.current_currency_for_locale/2`\n* Adds `Cldr.Currency.territory_currencies/0`\n\nSome examples:\n```\niex> Cldr.Currency.territory_currencies |> Map.get(\"LT\")\n%{\n  EUR: %{from: ~D[2015-01-01], to: nil},\n  LTL: %{from: nil, to: ~D[2014-12-31]},\n  LTT: %{from: nil, to: ~D[1993-06-25]},\n  SUR: %{from: nil, to: ~D[1992-10-01]}\n}\n\niex> Cldr.Currency.currency_history_for_locale \"en\", MyApp.Cldr\n%{\n  USD: %{from: ~D[1792-01-01], to: nil},\n  USN: %{tender: false},\n  USS: %{from: nil, tender: false, to: ~D[2014-03-01]}\n}\n\niex> Cldr.Currency.current_currency_for_locale \"en\", MyApp.Cldr\n:USD\n\niex> Cldr.Currency.current_currency_for_locale \"en-AU\", MyApp.Cldr\n:AUD\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.1.4 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.1.4 released on February 22nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-1-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes significant performance regression in `Cldr.Currency.currencies_for_locale/2`.  Thanks to @doughsay for the issue.  Closes #98 in [money](https://github.com/elixir-cldr/money).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.1.3 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.1.3 released on February 18th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-1-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Updates `ex_cldr` to fix the regex that parses currency names used for money parsing","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.1.2 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.1.2 released on February 13th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-1-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Some different currencies may have the same currency name.  This most commonly happens when there are historic currencies with the same name as a current currency. Afghan Afghanis, for example, has the code `:AFA` until 2002 when it was replaced by the currency code `:AFN`.  Now when extracting currency strings, the currency names map only to the current currency and the duplicated are therefore removed.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Currencies v2.1.1 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.1.1 released on February 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-1-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes the regex for parsing currency names that have date ranges in them. It now correctly parses names with non-ASCII characters too.\n\n* Removes `Cldr.Currency.all_currency_strings/2` since strings conflict across locales\n\n* Add `Cldr.Currency.currency_strings/2`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added `:unannotated` to `Cldr.Currency.currency_filter/2`.  It omits currency names that have a \"(...)\" in then since these are typically financial instruments.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.1.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.1.0 released on February 9th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"The primary goal of this release is to provide a mechanism to support parsing money and currency input from a user. With this in mind, this release adds:\n\n* `Cldr.Currency.currency_strings/2` that returns a list of strings for a currency in a locale against which user input can be compared to identify a currency\n\n* `Cldr.Currency.all_currency_strings/2` which returns a similar list but for all known locales\n\n* `Cldr.Currency.currency_filter/2` that will filter a list currencies based upon whether they are current, historic or legal tender\n\nIn addition the `Cldr.Currency.t` structure has changed:\n\n* The `Cldr.Currency.t` struct now includes effective dates `:to` and `:from`.  These were previously encoded in the currency name.  The currency name no longer includes these dates.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Currencies v2.0.0 - Changelog","doc":"This is the changelog for Cldr_Currencies v2.0.0 released on November 22nd, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_currencies/tags)","ref":"changelog.html#cldr_currencies-v2-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated dependency on [ex_cldr](https://hex.pm/packages/ex_cldr) to version 2.0.0.\n* Remove Poison from optional dependencies (can still be configured in a client app)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* `Currency.currency_for_code/3` has a changed function signature and it now requires a backend module to be specified.  It also supports an option `:locale` to specify the locale. The default is the default locale of the specified backend.\n```\n  Cldr.Currency.currency_for_locale(:USD, MyApp.Cldr, locale: \"en\")\n```\nThe @spec for the new signature is:\n```\n  @spec currency_for_code(code, Cldr.backend(), Keyword.t()) ::\n          {:ok, t} | {:error, {module(), String.t()}}\n```","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2018 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}